window.Gleam.initSearch([{"doc":"p5js_gleam","title":"p5js_gleam","content":"# p5js_gleam\n\nA simple game library providing [p5js](https://p5js.org/) bindings for Gleam in a functional style to make basic games and animations. Heavily inspired by the Racket library 2htdp/universe.\n\nThis project is primarily made up of\n\n- A [bun](https://bun.sh/) script that is used to generate bindings for p5js class methods\n  - Script is based on script created for [glare](https://github.com/Enderchief/glare/tree/master/scripts)\n- A wrapper game engine that provides a functional interface to p5js\n\n## Using the library\n\nAdd the library to your project by running the following command\n\n```bash\ngleam add p5js_gleam\n```\n\nThen add a call to the `start_sketch` function in your main function.\n\n```gleam\nimport p5js_gleam.{type P5, SketchConfig}\nimport p5js_gleam/bindings as p5\nimport gleam/option\n\nfn setup(p: P5) -&gt; String {\n  p5.create_canvas(p, 800.0, 600.0)\n  &quot;Hello, world!&quot;\n}\n\nfn draw(p: P5, state: String) -&gt; Nil {\n  p5.background(p, &quot;#ffffff&quot;)\n  p5.fill(p, &quot;#000000&quot;)\n  p5.text(p, state, 400.0, 300.0)\n  Nil\n}\n\npub fn main() {\n  p5.start_sketch(SketchConfig(\n    init: setup,\n    draw: draw,\n    on_tick: option.None,\n    on_key: option.None,\n    on_mouse: option.None,\n  ))\n}\n```\n\nAfterwards you will need to build your project and include it in an html file. The html file must import p5js as a module before the generated javascript file. The easiest way to do this is to load the p5js library from a CDN.\n\n```html\n&lt;!doctype html&gt;\n&lt;html lang=&quot;en&quot;&gt;\n  &lt;head&gt;\n    &lt;meta charset=&quot;UTF-8&quot; /&gt;\n    &lt;meta http-equiv=&quot;X-UA-Compatible&quot; content=&quot;IE=edge&quot; /&gt;\n    &lt;meta name=&quot;viewport&quot; content=&quot;width=device-width, initial-scale=1.0&quot; /&gt;\n    &lt;title&gt;Ball Spawner&lt;/title&gt;\n    &lt;script src=&quot;https://cdn.jsdelivr.net/npm/p5@1.9.2/lib/p5.js&quot;&gt;&lt;/script&gt;\n    &lt;script type=&quot;module&quot;&gt;\n      import { main } from &quot;./ball_spawner.js&quot;;\n      main();\n    &lt;/script&gt;\n  &lt;/head&gt;\n  &lt;body&gt;&lt;/body&gt;\n&lt;/html&gt;\n```\n\nTo see the library in action you can serve one of the examples in the `examples` directory.\n\n## Generating FFI Bindings\n\nTo generate the FFI bindings you will need bun installed. Once you have bun installed run\n\n```bash\nbun run ./scripts/generate_p5.ts\n```\n","url":"index.html"},{"doc":"p5js_gleam","title":"P5","content":"pub type P5\n A reference to the P5js library. Primarily used to access the P5js APIs for drawing.\n\nSynonyms:\np5js_gleam.P5\np5js_gleam P5","url":"p5js_gleam.html#P5"},{"doc":"p5js_gleam","title":"SketchConfig","content":"pub type SketchConfig(model) {\n  SketchConfig(\n    init: fn(P5) -&gt; model,\n    draw: fn(P5, model) -&gt; Nil,\n    on_tick: Option(fn(model) -&gt; model),\n    on_key: Option(fn(String, model) -&gt; model),\n    on_mouse: Option(fn(Float, Float, model) -&gt; model),\n  )\n}\n Configuration to start a sketch. Requires an init function to create the initial model, and a draw function to draw the model. Optionally, you can provide an on_tick function to update the model on each frame, an on_key function to handle key events, and an on_mouse function to handle mouse events.\nSketchConfig(\n  init: fn(P5) -&gt; model,\n  draw: fn(P5, model) -&gt; Nil,\n  on_tick: Option(fn(model) -&gt; model),\n  on_key: Option(fn(String, model) -&gt; model),\n  on_mouse: Option(fn(Float, Float, model) -&gt; model),\n)\n\ninit\n&lt;p&gt;The init function takes a reference to the P5js library and returns the initial model. It should also create the canvas/do any P5 specific initialization.&lt;/p&gt;\n\ndraw\n&lt;p&gt;The draw function takes a reference to the P5js library and the current model then renders it to the screen.&lt;/p&gt;\n\non_tick\n&lt;p&gt;on_tick functions take the current model, and return the updated model for the next frame.&lt;/p&gt;\n\non_key\n&lt;p&gt;on_key functions take a string representing the key that was pressed, and the current model, and return the updated model.&lt;/p&gt;\n\non_mouse\n&lt;p&gt;on_mouse functions take the x and y coordinates of the mouse, and the current model, and return the updated model.&lt;/p&gt;\n\nSynonyms:\np5js_gleam.SketchConfig\np5js_gleam SketchConfig","url":"p5js_gleam.html#SketchConfig"},{"doc":"p5js_gleam","title":"p5js_gleam","content":"","url":"p5js_gleam.html"},{"doc":"p5js_gleam/bindings","title":"background","content":"pub fn background(p: P5, color: String) -&gt; P5\n A binding to the p5.js `background` function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.background\np5js_gleam/bindings background","url":"p5js_gleam/bindings.html#background"},{"doc":"p5js_gleam/bindings","title":"circle","content":"pub fn circle(\n  p: P5,\n  x_center: Float,\n  y_center: Float,\n  radius: Float,\n) -&gt; P5\n A binding to the p5.js `circle` function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.circle\np5js_gleam/bindings circle","url":"p5js_gleam/bindings.html#circle"},{"doc":"p5js_gleam/bindings","title":"create_canvas","content":"pub fn create_canvas(p: P5, width: Float, height: Float) -&gt; P5\n A binding to the p5.js `createCanvas` function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.create_canvas\np5js_gleam/bindings create_canvas","url":"p5js_gleam/bindings.html#create_canvas"},{"doc":"p5js_gleam/bindings","title":"ellipse","content":"pub fn ellipse(\n  p: P5,\n  x_center: Float,\n  y_center: Float,\n  width: Float,\n  height: Float,\n) -&gt; P5\n A binding to the p5.js `ellipse` function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.ellipse\np5js_gleam/bindings ellipse","url":"p5js_gleam/bindings.html#ellipse"},{"doc":"p5js_gleam/bindings","title":"fill","content":"pub fn fill(p: P5, color_hex: String) -&gt; P5\n A binding to the p5.js `fill` function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.fill\np5js_gleam/bindings fill","url":"p5js_gleam/bindings.html#fill"},{"doc":"p5js_gleam/bindings","title":"line","content":"pub fn line(\n  p: P5,\n  point1_x: Float,\n  point1_y: Float,\n  point2_x: Float,\n  point2_y: Float,\n) -&gt; P5\n A binding to the p5.js `line` function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.line\np5js_gleam/bindings line","url":"p5js_gleam/bindings.html#line"},{"doc":"p5js_gleam/bindings","title":"quad","content":"pub fn quad(\n  p: P5,\n  p1_x: Float,\n  p1_y: Float,\n  p2_x: Float,\n  p2_y: Float,\n  p3_x: Float,\n  p3_y: Float,\n  p4_x: Float,\n  p4_y: Float,\n) -&gt; P5\n A binding to the p5.js `quad` function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.quad\np5js_gleam/bindings quad","url":"p5js_gleam/bindings.html#quad"},{"doc":"p5js_gleam/bindings","title":"rectangle","content":"pub fn rectangle(\n  p: P5,\n  top_left_x: Float,\n  top_left_y: Float,\n  width: Float,\n  height: Float,\n) -&gt; P5\n A binding to the p5.js `rectangle` function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.rectangle\np5js_gleam/bindings rectangle","url":"p5js_gleam/bindings.html#rectangle"},{"doc":"p5js_gleam/bindings","title":"square","content":"pub fn square(\n  p: P5,\n  top_left_x: Float,\n  top_left_y: Float,\n  side_length: Float,\n) -&gt; P5\n A binding to the p5.js `square` function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.square\np5js_gleam/bindings square","url":"p5js_gleam/bindings.html#square"},{"doc":"p5js_gleam/bindings","title":"start_sketch","content":"pub fn start_sketch(config: SketchConfig(a)) -&gt; Nil\n Starts a p5.js sketch with the given configuration.\nSynonyms:\np5js_gleam/bindings.start_sketch\np5js_gleam/bindings start_sketch","url":"p5js_gleam/bindings.html#start_sketch"},{"doc":"p5js_gleam/bindings","title":"stroke","content":"pub fn stroke(p: P5, color_hex: String) -&gt; P5\n A binding to the p5.js `stroke` function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.stroke\np5js_gleam/bindings stroke","url":"p5js_gleam/bindings.html#stroke"},{"doc":"p5js_gleam/bindings","title":"stroke_weight","content":"pub fn stroke_weight(p: P5, weight: Int) -&gt; P5\n A binding to the p5.js `strokeWeight` function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.stroke_weight\np5js_gleam/bindings stroke_weight","url":"p5js_gleam/bindings.html#stroke_weight"},{"doc":"p5js_gleam/bindings","title":"text","content":"pub fn text(\n  p: P5,\n  text: String,\n  bottom_corner_x: Float,\n  bottom_corner_y: Float,\n) -&gt; P5\n A binding to the p5.js `text` function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.text\np5js_gleam/bindings text","url":"p5js_gleam/bindings.html#text"},{"doc":"p5js_gleam/bindings","title":"text_size","content":"pub fn text_size(p: P5, size: Int) -&gt; P5\n A binding to the p5.js `textSize` function. Takes a p5 instance and the function&#39;s arguments and returns the p5 instance.\nSynonyms:\np5js_gleam/bindings.text_size\np5js_gleam/bindings text_size","url":"p5js_gleam/bindings.html#text_size"},{"doc":"p5js_gleam/bindings","title":"p5js_gleam/bindings","content":"","url":"p5js_gleam/bindings.html"}]);